@@ -27,7 +27,13 @@ sub _build_home {
     my $self = shift;
     my $home =
         Path::Class::Dir->new( File::HomeDir->my_home, '.TimeTracker' );
-    $home->mkpath unless -d $home;
+    unless (-d $home) {
+        $home->mkpath;
+        $self->_write_config_file_locations({});
+        my $fh = $self->global_config_file->openw;
+        print $fh $self->json_decoder->encode({});
+        close $fh;
+    }
     return $home;
 }
 
@@ -220,7 +226,7 @@ App::TimeTracker::Proto - App::TimeTracker Proto Class
 
 =head1 VERSION
 
-version 2.010
+version 2.011
 
 =head1 DESCRIPTION
 
